#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.2
visibility:           public
id:                   hslua-classes-2.3.2-1k4N5o5d9es2zZfCMeBTMA
key:                  hslua-classes-2.3.2-1k4N5o5d9es2zZfCMeBTMA
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2026 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  d080541f63264f289a81933af6854e6a
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.2-1k4N5o5d9es2zZfCMeBTMA
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hslua-core-2.3.2.1-3tsNfZ2PPMpIrGoJYp3SDj
    hslua-marshalling-2.3.2-EQCZTvqDYkhHetwO8kOojF text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

